==> distribution-6.0.0-dev.128.zip: drr/standards/iosco/upi/validation/exists/AnnaDsbMETLOnlyExistsValidator.java <==
package drr.standards.iosco.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidationResult.ValidationType;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.standards.iosco.upi.AnnaDsbAdditionalSubProduct;
import drr.standards.iosco.upi.AnnaDsbMETL;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class AnnaDsbMETLOnlyExistsValidator implements ValidatorWithArg<AnnaDsbMETL, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends AnnaDsbMETL> ValidationResult<AnnaDsbMETL> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("NPRM", ExistenceChecker.isSet((AnnaDsbAdditionalSubProduct) o.getNPRM()))
				.put("PRME", ExistenceChecker.isSet((AnnaDsbAdditionalSubProduct) o.getPRME()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("AnnaDsbMETL", ValidationType.ONLY_EXISTS, "AnnaDsbMETL", path, "");
		}
		return failure("AnnaDsbMETL", ValidationType.ONLY_EXISTS, "AnnaDsbMETL", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}

==> distribution-7.0.0-dev.101.zip: drr/standards/iosco/upi/validation/exists/AnnaDsbMETLOnlyExistsValidator.java <==
package drr.standards.iosco.upi.validation.exists;

import com.google.common.collect.ImmutableMap;
import com.rosetta.model.lib.path.RosettaPath;
import com.rosetta.model.lib.validation.ExistenceChecker;
import com.rosetta.model.lib.validation.ValidationResult;
import com.rosetta.model.lib.validation.ValidatorWithArg;
import drr.standards.iosco.upi.AnnaDsbAdditionalSubProduct;
import drr.standards.iosco.upi.AnnaDsbMETL;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

import static com.rosetta.model.lib.validation.ValidationResult.failure;
import static com.rosetta.model.lib.validation.ValidationResult.success;

public class AnnaDsbMETLOnlyExistsValidator implements ValidatorWithArg<AnnaDsbMETL, Set<String>> {

	/* Casting is required to ensure types are output to ensure recompilation in Rosetta */
	@Override
	public <T2 extends AnnaDsbMETL> ValidationResult<AnnaDsbMETL> validate(RosettaPath path, T2 o, Set<String> fields) {
		Map<String, Boolean> fieldExistenceMap = ImmutableMap.<String, Boolean>builder()
				.put("NPRM", ExistenceChecker.isSet((AnnaDsbAdditionalSubProduct) o.getNPRM()))
				.put("PRME", ExistenceChecker.isSet((AnnaDsbAdditionalSubProduct) o.getPRME()))
				.build();
		
		// Find the fields that are set
		Set<String> setFields = fieldExistenceMap.entrySet().stream()
				.filter(Map.Entry::getValue)
				.map(Map.Entry::getKey)
				.collect(Collectors.toSet());
		
		if (setFields.equals(fields)) {
			return success("AnnaDsbMETL", ValidationResult.ValidationType.ONLY_EXISTS, "AnnaDsbMETL", path, "");
		}
		return failure("AnnaDsbMETL", ValidationResult.ValidationType.ONLY_EXISTS, "AnnaDsbMETL", path, "",
				String.format("[%s] should only be set.  Set fields: %s", fields, setFields));
	}
}
